[![Build Status on Azure Pipelines](https://dev.azure.com/igraph-team/igraph/_apis/build/status/igraph.igraph?branchName=master)](https://dev.azure.com/igraph-team/igraph/_build/latest?definitionId=1&branchName=master)
![Build Status on Github Actions](https://github.com/igraph/igraph/workflows/MINGW/badge.svg?branch=master)
[![codecov](https://codecov.io/gh/igraph/igraph/branch/master/graph/badge.svg?token=xGFabHJE2I)](https://codecov.io/gh/igraph/igraph)
[![DOI](https://zenodo.org/badge/8546198.svg)](https://zenodo.org/badge/latestdoi/8546198)

The igraph library
------------------

igraph is a C library for creating, manipulating and analysing graphs.
It is intended to be as powerful (i.e. fast) as possible to enable
working with large graphs.

See https://igraph.org for installation instructions
and documentation.

igraph can also be used from:

 - R — https://github.com/igraph/rigraph
 - Python — https://github.com/igraph/python-igraph
 - Mathematica — https://github.com/szhorvat/IGraphM
